"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useFlipperDevtools;

var React = _interopRequireWildcard(require("react"));

var _flatted = require("flatted");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

let FlipperModule;

try {
  FlipperModule = require('react-native-flipper');
} catch (error) {// do nothing
}

function useFlipperDevtools(queryClient) {
  if (FlipperModule == null) {
    throw new Error(`Please install the 'react-native-flipper' package in your project to use Flipper integration for React Query`);
  }

  const {
    addPlugin
  } = FlipperModule;
  const queryCache = queryClient.getQueryCache();
  const unsubscribeRef = React.useRef();

  function unsubscribe() {
    if (unsubscribeRef.current) {
      unsubscribeRef.current();
      unsubscribeRef.current = undefined;
    }
  }

  React.useEffect(() => {
    addPlugin({
      getId() {
        return 'react-query-devtools-flipper';
      },

      onConnect(connection) {
        function sendQueries() {
          connection.send('queries', {
            queries: (0, _flatted.stringify)(Object.values(queryCache.findAll()))
          });
        } // hydrate the initial state


        sendQueries();
        unsubscribeRef.current = queryCache.subscribe(() => {
          sendQueries();
        });
        connection.receive('refetchQuery', (queryKey, responder) => {
          const query = queryCache.find(queryKey);

          if (query) {
            query.fetch().then(() => responder.success(), error => responder.error(error));
          }
        });
        connection.receive('invalidateQuery', (queryKey, responder) => {
          queryClient.invalidateQueries(queryKey).then(() => responder.success(), error => responder.error(error));
        });
        connection.receive('resetQuery', (queryKey, responder) => {
          queryClient.resetQueries(queryKey).then(() => responder.success(), error => responder.error(error));
        });
        connection.receive('removeQuery', (queryKey, responder) => {
          queryClient.removeQueries(queryKey);
          responder.success();
        });
      },

      onDisconnect() {
        unsubscribe();
      },

      runInBackground: () => true
    });
    return () => {
      unsubscribe();
    };
  }, [addPlugin, queryCache, queryClient]);
}
//# sourceMappingURL=useFlipperDevtools.js.map